@@ -19,11 +19,13 @@ from ..mobilecommand import MobileCommand as Command
 
 class Applications(webdriver.Remote):
     def background_app(self, seconds):
-        """Puts the application in the background on the device for a certain
-        duration.
+        """Puts the application in the background on the device for a certain duration.
 
-        :Args:
-         - seconds - the duration for the application to remain in the background
+        Args:
+            seconds (int): the duration for the application to remain in the background
+
+        Returns:
+            `WebDriver`
         """
         data = {
             'seconds': seconds,
@@ -32,11 +34,13 @@ class Applications(webdriver.Remote):
         return self
 
     def is_app_installed(self, bundle_id):
-        """Checks whether the application specified by `bundle_id` is installed
-        on the device.
+        """Checks whether the application specified by `bundle_id` is installed on the device.
 
-        :Args:
-         - bundle_id - the id of the application to query
+        Args:
+            bundle_id (int): the id of the application to query
+
+        Returns:
+            bool: `True` if app is installed
         """
         data = {
             'bundleId': bundle_id,
@@ -46,20 +50,22 @@ class Applications(webdriver.Remote):
     def install_app(self, app_path, **options):
         """Install the application found at `app_path` on the device.
 
-        :Args:
-         - app_path - the local or remote path to the application to install
-         - options - the possible installation options.
-         The following options are available for Android:
-         `replace`: whether to reinstall/upgrade the package if it is
-         already present on the device under test. True by default
-         `timeout`: how much time to wait for the installation to complete.
-         60000ms by default.
-         `allowTestPackages`: whether to allow installation of packages marked
-         as test in the manifest. False by default
-         `useSdcard`: whether to use the SD card to install the app. False
-         by default
-         `grantPermissions`: whether to automatically grant application permissions
-         on Android 6+ after the installation completes. False by default
+        Args:
+            app_path (str): the local or remote path to the application to install
+
+        Keyword Args:
+            replace (bool): [Android only] whether to reinstall/upgrade the package if it is
+                already present on the device under test. True by default
+            timeout (int): [Android only] how much time to wait for the installation to complete.
+                60000ms by default.
+            allowTestPackages (bool): [Android only] whether to allow installation of packages marked
+                as test in the manifest. False by default
+            useSdcard (bool): [Android only] whether to use the SD card to install the app. False by default
+            grantPermissions (bool): [Android only] whether to automatically grant application permissions
+                on Android 6+ after the installation completes. False by default
+
+        Returns:
+            `WebDriver`
         """
         data = {
             'appPath': app_path,
@@ -72,14 +78,17 @@ class Applications(webdriver.Remote):
     def remove_app(self, app_id, **options):
         """Remove the specified application from the device.
 
-        :Args:
-         - app_id - the application id to be removed
-         - options - the possible removal options.
-         The following options are available for Android:
-         `keepData`: whether to keep application data and caches after it is uninstalled.
-         False by default
-         `timeout`: how much time to wait for the uninstall to complete.
-         20000ms by default.
+        Args:
+            app_id (str): the application id to be removed
+
+        Keyword Args:
+            keepData (bool): [Android only] whether to keep application data and caches after it is uninstalled.
+                False by default
+            timeout (int): [Android only] how much time to wait for the uninstall to complete.
+                20000ms by default.
+
+        Returns:
+            `WebDriver`
         """
         data = {
             'appId': app_id,
@@ -91,6 +100,9 @@ class Applications(webdriver.Remote):
 
     def launch_app(self):
         """Start on the device the application specified in the desired capabilities.
+
+        Returns:
+            `WebDriver`
         """
         self.execute(Command.LAUNCH_APP)
         return self
@@ -98,6 +110,9 @@ class Applications(webdriver.Remote):
     def close_app(self):
         """Stop the running application, specified in the desired capabilities, on
         the device.
+
+        Returns:
+            `WebDriver`
         """
         self.execute(Command.CLOSE_APP)
         return self
@@ -105,14 +120,15 @@ class Applications(webdriver.Remote):
     def terminate_app(self, app_id, **options):
         """Terminates the application if it is running.
 
-        :Args:
-         - app_id - the application id to be terminates
-         - options - the possible termination options.
-         The following options are available for Android:
-         `timeout`: how much time to wait for the uninstall to complete.
-         500ms by default.
+        Args:
+            app_id (str): the application id to be terminates
 
-        :return: True if the app has been successfully terminated
+        Keyword Args:
+            `timeout` (int): [Android only] how much time to wait for the uninstall to complete.
+                500ms by default.
+
+        Returns:
+            bool: True if the app has been successfully terminated
         """
         data = {
             'appId': app_id,
@@ -125,10 +141,11 @@ class Applications(webdriver.Remote):
         """Activates the application if it is not running
         or is running in the background.
 
-        :Args:
-         - app_id - the application id to be activated
+        Args:
+            app_id (str): the application id to be activated
 
-        :return: self instance for chaining
+        Returns:
+            `WebDriver`
         """
         data = {
             'appId': app_id,
@@ -139,11 +156,12 @@ class Applications(webdriver.Remote):
     def query_app_state(self, app_id):
         """Queries the state of the application.
 
-        :Args:
-         - app_id - the application id to be queried
+        Args:
+            app_id (str): the application id to be queried
 
-        :return: One of possible application state constants. See ApplicationState
-        class for more details.
+        Returns:
+            One of possible application state constants. See ApplicationState
+            class for more details.
         """
         data = {
             'appId': app_id,
@@ -154,9 +172,9 @@ class Applications(webdriver.Remote):
         """Returns the application strings from the device for the specified
         language.
 
-        :Args:
-         - language - strings language code
-         - string_file - the name of the string file to query
+        Args:
+            language (str): strings language code
+            string_file (str): the name of the string file to query
         """
         data = {}
         if language != None:
@@ -165,6 +183,12 @@ class Applications(webdriver.Remote):
             data['stringFile'] = string_file
         return self.execute(Command.GET_APP_STRINGS, data)['value']
 
+    def reset(self):
+        """Resets the current application on the device.
+        """
+        self.execute(Command.RESET)
+        return self
+
     # pylint: disable=protected-access
 
     def _addCommands(self):
@@ -184,3 +208,5 @@ class Applications(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/app_state')
         self.command_executor._commands[Command.GET_APP_STRINGS] = \
             ('POST', '/session/$sessionId/appium/app/strings')
+        self.command_executor._commands[Command.RESET] = \
+            ('POST', '/session/$sessionId/appium/app/reset')
