@@ -40,6 +40,7 @@ from .extensions.applications import Applications
 from .extensions.clipboard import Clipboard
 from .extensions.context import Context
 from .extensions.device_time import DeviceTime
+from .extensions.execute_driver import ExecuteDriver
 from .extensions.hw_actions import HardwareActions
 from .extensions.images_comparison import ImagesComparison
 from .extensions.ime import IME
@@ -116,6 +117,7 @@ class WebDriver(
     Context,
     DeviceTime,
     Display,
+    ExecuteDriver,
     Gsm,
     HardwareActions,
     ImagesComparison,
@@ -192,15 +194,15 @@ class WebDriver(
         self._addCommands()
 
     def start_session(self, capabilities, browser_profile=None):
-        """
-        Override for Appium
-        Creates a new session with the desired capabilities.
+        """Creates a new session with the desired capabilities.
 
-        :Args:
-         - automation_name - The name of automation engine to use.
-         - platform_name - The name of target platform.
-         - platform_version - The kind of mobile device or emulator to use
-         - app - The absolute local path or remote http URL to an .ipa or .apk file, or a .zip containing one of these.
+        Override for Appium
+
+        Args:
+            automation_name: The name of automation engine to use.
+            platform_name: The name of target platform.
+            platform_version: The kind of mobile device or emulator to use
+            app: The absolute local path or remote http URL to an .ipa or .apk file, or a .zip containing one of these.
 
         Read https://github.com/appium/appium/blob/master/docs/en/writing-running-appium/caps.md for more details.
         """
@@ -230,8 +232,7 @@ class WebDriver(
         self.command_executor.w3c = self.w3c
 
     def _merge_capabilities(self, capabilities):
-        """
-        Manage capabilities whether W3C format or MJSONWP format
+        """Manage capabilities whether W3C format or MJSONWP format
         """
         if _FORCE_MJSONWP in capabilities:
             force_mjsonwp = capabilities[_FORCE_MJSONWP]
@@ -244,14 +245,17 @@ class WebDriver(
         return {'capabilities': w3c_caps, 'desiredCapabilities': capabilities}
 
     def find_element(self, by=By.ID, value=None):
-        """
-        Override for Appium
-        'Private' method used by the find_element_by_* methods.
+        """'Private' method used by the find_element_by_* methods.
 
-        :Usage:
+        Override for Appium
+
+        Usage:
             Use the corresponding find_element_by_* instead of this.
 
-        :rtype: WebElement
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         # TODO: If we need, we should enable below converter for Web context
         # if self.w3c:
@@ -272,14 +276,17 @@ class WebDriver(
             'value': value})['value']
 
     def find_elements(self, by=By.ID, value=None):
-        """
-        Override for Appium
-        'Private' method used by the find_elements_by_* methods.
+        """'Private' method used by the find_elements_by_* methods.
 
-        :Usage:
+        Override for Appium
+
+        Usage:
             Use the corresponding find_elements_by_* instead of this.
 
-        :rtype: list of WebElement
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         # TODO: If we need, we should enable below converter for Web context
         # if self.w3c:
@@ -305,123 +312,179 @@ class WebDriver(
     def find_element_by_ios_uiautomation(self, uia_string):
         """Finds an element by uiautomation in iOS.
 
-        :Args:
-         - uia_string - The element name in the iOS UIAutomation library
+        Args:
+            uia_string (str): The element name in the iOS UIAutomation library
 
-        :Usage:
+        Usage:
             driver.find_element_by_ios_uiautomation('.elements()[1].cells()[2]')
+
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         return self.find_element(by=MobileBy.IOS_UIAUTOMATION, value=uia_string)
 
     def find_elements_by_ios_uiautomation(self, uia_string):
         """Finds elements by uiautomation in iOS.
 
-        :Args:
-         - uia_string - The element name in the iOS UIAutomation library
+        Args:
+            uia_string: The element name in the iOS UIAutomation library
 
-        :Usage:
+        Usage:
             driver.find_elements_by_ios_uiautomation('.elements()[1].cells()[2]')
+
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         return self.find_elements(by=MobileBy.IOS_UIAUTOMATION, value=uia_string)
 
     def find_element_by_ios_predicate(self, predicate_string):
         """Find an element by ios predicate string.
 
-        :Args:
-         - predicate_string - The predicate string
+        Args:
+            predicate_string (str): The predicate string
 
-        :Usage:
+        Usage:
             driver.find_element_by_ios_predicate('label == "myLabel"')
+
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         return self.find_element(by=MobileBy.IOS_PREDICATE, value=predicate_string)
 
     def find_elements_by_ios_predicate(self, predicate_string):
         """Finds elements by ios predicate string.
 
-        :Args:
-         - predicate_string - The predicate string
+        Args:
+            predicate_string (str): The predicate string
 
-        :Usage:
+        Usage:
             driver.find_elements_by_ios_predicate('label == "myLabel"')
+
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         return self.find_elements(by=MobileBy.IOS_PREDICATE, value=predicate_string)
 
     def find_element_by_ios_class_chain(self, class_chain_string):
         """Find an element by ios class chain string.
 
-        :Args:
-         - class_chain_string - The class chain string
+        Args:
+            class_chain_string (str): The class chain string
 
-        :Usage:
+        Usage:
             driver.find_element_by_ios_class_chain('XCUIElementTypeWindow/XCUIElementTypeButton[3]')
+
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         return self.find_element(by=MobileBy.IOS_CLASS_CHAIN, value=class_chain_string)
 
     def find_elements_by_ios_class_chain(self, class_chain_string):
         """Finds elements by ios class chain string.
 
-        :Args:
-         - class_chain_string - The class chain string
+        Args:
+            class_chain_string (str): The class chain string
 
-        :Usage:
+        Usage:
             driver.find_elements_by_ios_class_chain('XCUIElementTypeWindow[2]/XCUIElementTypeAny[-2]')
+
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         return self.find_elements(by=MobileBy.IOS_CLASS_CHAIN, value=class_chain_string)
 
     def find_element_by_android_uiautomator(self, uia_string):
         """Finds element by uiautomator in Android.
 
-        :Args:
-         - uia_string - The element name in the Android UIAutomator library
+        Args:
+            uia_string: The element name in the Android UIAutomator library
 
-        :Usage:
+        Usage:
             driver.find_element_by_android_uiautomator('.elements()[1].cells()[2]')
+
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         return self.find_element(by=MobileBy.ANDROID_UIAUTOMATOR, value=uia_string)
 
     def find_elements_by_android_uiautomator(self, uia_string):
         """Finds elements by uiautomator in Android.
 
-        :Args:
-         - uia_string - The element name in the Android UIAutomator library
+        Args:
+            uia_string (str): The element name in the Android UIAutomator library
 
-        :Usage:
+        Usage:
             driver.find_elements_by_android_uiautomator('.elements()[1].cells()[2]')
+
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         return self.find_elements(by=MobileBy.ANDROID_UIAUTOMATOR, value=uia_string)
 
     def find_element_by_android_viewtag(self, tag):
         """Finds element by [View#tags](https://developer.android.com/reference/android/view/View#tags) in Android.
+
         It works with [Espresso Driver](https://github.com/appium/appium-espresso-driver).
 
-        :Args:
-         - tag - The tag name of the view to look for
+        Args:
+            tag (str): The tag name of the view to look for
 
-        :Usage:
+        Usage:
             driver.find_element_by_android_viewtag('a tag name')
+
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         return self.find_element(by=MobileBy.ANDROID_VIEWTAG, value=tag)
 
     def find_elements_by_android_viewtag(self, tag):
         """Finds element by [View#tags](https://developer.android.com/reference/android/view/View#tags) in Android.
+
         It works with [Espresso Driver](https://github.com/appium/appium-espresso-driver).
 
-        :Args:
-         - tag - The tag name of the view to look for
+        Args:
+            tag (str): The tag name of the view to look for
 
-        :Usage:
+        Usage:
             driver.find_elements_by_android_viewtag('a tag name')
+
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         return self.find_elements(by=MobileBy.ANDROID_VIEWTAG, value=tag)
 
     def find_element_by_image(self, img_path):
         """Finds a portion of a screenshot by an image.
+
         Uses driver.find_image_occurrence under the hood.
 
-        :Args:
-        - img_path - a string corresponding to the path of a image
+        Args:
+            img_path (str): a string corresponding to the path of a image
 
-        :return: an Element object
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         with open(img_path, 'rb') as i_file:
             b64_data = base64.b64encode(i_file.read()).decode('UTF-8')
@@ -430,13 +493,17 @@ class WebDriver(
 
     def find_elements_by_image(self, img_path):
         """Finds a portion of a screenshot by an image.
+
         Uses driver.find_image_occurrence under the hood. Note that this will
         only ever return at most one element
 
-        :Args:
-        - img_path - a string corresponding to the path of a image
+        Args:
+            img_path (str): a string corresponding to the path of a image
 
-        :return: possibly-empty list of Elements
+        Return:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         with open(img_path, 'rb') as i_file:
             b64_data = base64.b64encode(i_file.read()).decode('UTF-8')
@@ -446,76 +513,103 @@ class WebDriver(
     def find_element_by_accessibility_id(self, accessibility_id):
         """Finds an element by accessibility id.
 
-        :Args:
-         - accessibility_id - a string corresponding to a recursive element search using the
-         Id/Name that the native Accessibility options utilize
+        Args:
+            accessibility_id (str): A string corresponding to a recursive element search using the
+                Id/Name that the native Accessibility options utilize
 
-        :Usage:
+        Usage:
             driver.find_element_by_accessibility_id()
+
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         return self.find_element(by=MobileBy.ACCESSIBILITY_ID, value=accessibility_id)
 
     def find_elements_by_accessibility_id(self, accessibility_id):
         """Finds elements by accessibility id.
 
-        :Args:
-         - accessibility_id - a string corresponding to a recursive element search using the
-         Id/Name that the native Accessibility options utilize
+        Args:
+            accessibility_id (str): a string corresponding to a recursive element search using the
+                Id/Name that the native Accessibility options utilize
 
-        :Usage:
+        Usage:
             driver.find_elements_by_accessibility_id()
+
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         return self.find_elements(by=MobileBy.ACCESSIBILITY_ID, value=accessibility_id)
 
     def find_element_by_custom(self, selector):
         """Finds an element in conjunction with a custom element finding plugin
 
-        :Args:
-         - selector - a string of the form "module:selector", where "module" is
-           the shortcut name given in the customFindModules capability, and
-           "selector" is the string that will be passed to the custom element
-           finding plugin itself
+        Args:
+            selector (str): a string of the form "module:selector", where "module" is
+                the shortcut name given in the customFindModules capability, and
+                "selector" is the string that will be passed to the custom element
+                finding plugin itself
 
-        :Usage:
+        Usage:
             driver.find_element_by_custom("foo:bar")
+
+        Returns:
+            `WebElement`
+
+        :rtype: `MobileWebElement`
         """
         return self.find_element(by=MobileBy.CUSTOM, value=selector)
 
     def find_elements_by_custom(self, selector):
         """Finds elements in conjunction with a custom element finding plugin
 
-        :Args:
-         - selector - a string of the form "module:selector", where "module" is
-           the shortcut name given in the customFindModules capability, and
-           "selector" is the string that will be passed to the custom element
-           finding plugin itself
+        Args:
+            selector: a string of the form "module:selector", where "module" is
+                the shortcut name given in the customFindModules capability, and
+                "selector" is the string that will be passed to the custom element
+                finding plugin itself
 
-        :Usage:
+        Usage:
             driver.find_elements_by_custom("foo:bar")
+
+        Returns:
+            :obj:`list` of :obj:`WebElement`
+
+        :rtype: list of `MobileWebElement`
         """
         return self.find_elements(by=MobileBy.CUSTOM, value=selector)
 
-    def create_web_element(self, element_id):
-        """
-        Creates a web element with the specified element_id.
+    def create_web_element(self, element_id, w3c=False):
+        """Creates a web element with the specified element_id.
+
         Overrides method in Selenium WebDriver in order to always give them
         Appium WebElement
-        """
-        return MobileWebElement(self, element_id)
 
-    def reset(self):
-        """Resets the current application on the device.
+        Args:
+            element_id (int): The element id to create a web element
+            w3c (bool): Whether the element is W3C or MJSONWP
+
+        Returns:
+            `MobileWebElement`
         """
-        self.execute(Command.RESET)
-        return self
+        return MobileWebElement(self, element_id, w3c)
 
     def press_button(self, button_name):
-        """Sends a physical button name to the device to simulate the user pressing. iOS only.
+        """Sends a physical button name to the device to simulate the user pressing.
+
+        iOS only.
         Possible button names can be found in
         https://github.com/appium/WebDriverAgent/blob/master/WebDriverAgentLib/Categories/XCUIDevice%2BFBHelpers.h
 
-        :Args:
-         - button_name - the button name to be sent to the device
+        Args:
+            button_name (str): the button name to be sent to the device
+
+        Returns:
+            `WebDriver`
+
         """
         data = {
             'name': button_name
@@ -532,9 +626,12 @@ class WebDriver(
     def set_value(self, element, value):
         """Set the value on an element in the application.
 
-        :Args:
-         - element - the element whose value will be set
-         - Value - the value to set on the element
+        Args:
+            element (`WebElement`: the element whose value will be set
+            value (str): the value to set on the element
+
+        Returns:
+            `WebDriver`
         """
         data = {
             'id': element.id,
@@ -545,13 +642,16 @@ class WebDriver(
 
     def end_test_coverage(self, intent, path):
         """Ends the coverage collection and pull the coverage.ec file from the device.
+
         Android only.
+        See https://github.com/appium/appium/blob/master/docs/en/writing-running-appium/android/android-coverage.md
 
-        See https://github.com/appium/appium/blob/master/docs/en/android_coverage.md
+        Args:
+            intent (str): description of operation to be performed
+            path (str): path to coverage.ec file to be pulled from the device
 
-        :Args:
-         - intent - description of operation to be performed
-         - path - path to coverage.ec file to be pulled from the device
+        Returns:
+            TODO
         """
         data = {
             'intent': intent,
@@ -561,30 +661,33 @@ class WebDriver(
 
     def open_notifications(self):
         """Open notification shade in Android (API Level 18 and above)
+
+        Returns:
+            `WebDriver`
         """
         self.execute(Command.OPEN_NOTIFICATIONS, {})
         return self
 
     @property
     def battery_info(self):
-        """
-        Retrieves battery information for the device under test.
+        """Retrieves battery information for the device under test.
 
-        :return: A dictionary containing the following entries
-        - level: Battery level in range [0.0, 1.0], where 1.0 means 100% charge.
-        Any value lower than 0 means the level cannot be retrieved
-        - state: Platform-dependent battery state value.
-        On iOS (XCUITest):
-        - 1: Unplugged
-        - 2: Charging
-        - 3: Full
-        Any other value means the state cannot be retrieved
-        On Android (UIAutomator2):
-        - 2: Charging
-        - 3: Discharging
-        - 4: Not charging
-        - 5: Full
-        Any other value means the state cannot be retrieved
+        Returns:
+            A dictionary containing the following entries
+                level: Battery level in range [0.0, 1.0], where 1.0 means 100% charge.
+                    Any value lower than 0 means the level cannot be retrieved
+                state: Platform-dependent battery state value.
+                    On iOS (XCUITest):
+                        1: Unplugged
+                        2: Charging
+                        3: Full
+                        Any other value means the state cannot be retrieved
+                    On Android (UIAutomator2):
+                        2: Charging
+                        3: Discharging
+                        4: Not charging
+                        5: Full
+                        Any other value means the state cannot be retrieved
         """
         return self.execute_script('mobile: batteryInfo')
 
@@ -612,8 +715,6 @@ class WebDriver(
             ('POST', '/session/$sessionId/appium/app/close')
         self.command_executor._commands[Command.END_TEST_COVERAGE] = \
             ('POST', '/session/$sessionId/appium/app/end_test_coverage')
-        self.command_executor._commands[Command.RESET] = \
-            ('POST', '/session/$sessionId/appium/app/reset')
         self.command_executor._commands[Command.OPEN_NOTIFICATIONS] = \
             ('POST', '/session/$sessionId/appium/device/open_notifications')
         self.command_executor._commands[Command.REPLACE_KEYS] = \
